***********************************************************************************
***********************************************************************************
*****                                                                         *****
***** Replication Data Set for                                                *****
*****                                                                         *****
***** "Distributive Politics, Electoral Institutions, and European Structural *****
*****  and Investment Funding: Evidence from Italy and France"                *****
*****                                                                         *****
***** by Lisa Maria Dellmuth, Dominik Schraff, and Michael F. Stoffel         *****
*****                                                                         *****
***** to be published in the Journal of Common Market Studies                 *****
*****                                                                         *****
***********************************************************************************
***********************************************************************************




	
	
	* Vote share variance
		egen id=group(nuts2_name)
		xtset id
		bysort country: xtsum voteshare
		xtreg voteshare if country==0, i(id)
		xtreg voteshare if country==1, i(id)
	
	* Correlation between country and regional autonomy index
		esize twosample rai_nuts2, by(country) pbcorr
	

	
*** Analysis for Italy

	* Table 1, models 1 through 5
	
		set more off
		meglm erdf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity if country==0 & voteshare!=. || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m1
		meglm erdf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity voteshare if country==0 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m2
		meglm erdf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity c.voteshare##i.align if country==0 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m3
		meglm esf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity if country==0 & voteshare!=. || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m4
		meglm esf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity voteshare if country==0 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m5

				
	* Graphic of voteshare influence in model 2
		
		estimates restore m2
		quietly margins, at(voteshare =(34(1)67) ldensity=5.5088586 larea=7.9330798 lgdp=10.041908 lgdp_nuts2=9.6927665) predict(mu fixed)
		matrix p = r(table)'
		svmat p
		gen p = sum(1) + 33
		replace p = . if p>67
		gen p1_lo = p1 - 1.96*p2
		gen p1_up = p1 + 1.96*p2
		
		#delimit ;
		twoway
			(rarea p1_lo p1_up p,
				ytitle("") lwidth(none)
				xtitle("vote share", size(*1.171))
				xscale(range(34 67) noextend titlegap(small) noline)
				xlabel(35[5]65, labsize(medium) labgap(vsmall))
				ytitle("ERDF spending per capita", size(*1.171))
				title("")
				lwidth(none) 
				fcolor(gs11)
				lcolor(gs11))
			(line p1 p, lpattern(solid) lwidth(*1.7) lcolor(gs6)), 
				legend(off)
				graphregion(style(none) istyle(none) margin(zero))
				bgcolor(white) 
				plotregion(lcolor(black))
			;	
		#delimit cr	
			
			
			
	* Graphic for random effects of model 1
		
		estimates restore m1
		predict m1mean, reffects reses(m1se)
		gen upper = m1mean + 1.96*m1se
		gen lower = m1mean - 1.96*m1se
		drop if nuts2_name=="Valle d'Aosta/Valle d'Aoste"
		sort m1mean
		egen gruppe = group(m1mean)
		labmask gruppe, values(nuts2_name) // ssc install labutil //

		#delimit ;
		twoway
			(rcap upper lower gruppe,
				title("")
				graphregion(style(none) istyle(none) margin(zero)) 
				bgcolor(white) 
				plotregion(lcolor(black)) 
				xtitle("")
				xscale(range(1/19))
				xlabel(1/19, valuelabel angle(45) labsize(small) labgap(vsmall))
				lpattern(solid) lwidth(*1) lcolor(black)
				ytitle("random intercept size")
				ylabel(-1/2 ,nogrid labsize(small))
				yscale(titlegap(medsmall))
				yline(0, lcolor(gs10)))
			(scatter m1mean gruppe,
				msize(medsmall)
				mcolor(black)),
			legend(off)
		;
		#delimit cr


			

			
*** Analysis for France
	
	* Table 2, models 6 through 10
	
		set more off
		meglm erdf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity if country==1 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m6
		meglm erdf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity voteshare if country==1 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m7
		meglm erdf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity c.voteshare##i.align if country==1 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m8
		meglm esf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity if country==1 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m9
		meglm esf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity voteshare if country==1 || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		estimates store m10
		
		
	* Graphic of voteshare influence in model 6

		drop p1-p1_up
		estimates restore m7
		quietly margins, at(voteshare =(70(1)90)) predict(mu fixed)
		matrix p = r(table)'
		svmat p
		gen p = sum(1) + 69
		replace p = . if p>90
		gen p1_lo = p1 - 1.96*p2
		gen p1_up = p1 + 1.96*p2
			
		#delimit ;
		twoway
			(rarea p1_lo p1_up p,
				ytitle("") lwidth(none)
				xtitle("vote share", size(*1.171))
				xscale(titlegap(small) noline)
				xlabel(, labsize(medium) labgap(vsmall))
				ytitle("ERDF spending per capita", size(*1.171))
				title("")
				lwidth(none) 
				fcolor(gs11)
				lcolor(gs11))
			(line p1 p, lpattern(solid) lwidth(*1.7) lcolor(gs6)), 
				legend(off)
				graphregion(style(none) istyle(none) margin(zero))
				bgcolor(white)
				plotregion(lcolor(black))
			;	
		#delimit cr	

		
		
		
*** Joint Analysis
		
	* Graphic of interaction effect

		meglm erdf unemp_nuts2 lgdp_nuts2 unemp lgdp larea ldensity c.vsdevsd c.vsdevsd#country || nuts2_name: , family(gamma) link(log) covariance(unstructured)
		quietly margins r.country, at(vsdevsd=(-2(.1)2)) predict(mu fixedonly)
			
		drop p1-p1_up
		marginsplot	
		matrix p = r(table)'
		svmat p
		gen p = sum(1)/10 -2.1
		replace p = . if p>2
		gen p1_lo = p1 - 1.96*p2
		gen p1_up = p1 + 1.96*p2
		
		#delimit ;
		twoway
			(rarea p1_lo p1_up p,
				ytitle("") lwidth(none)
				xtitle("standardized vote share deviation", size(*1.171))
				xscale(titlegap(small) noline)
				xlabel(, labsize(medium) labgap(vsmall))
				ytitle("Difference IT-F in ERDF spending per capita", size(*1.171))
				title("")
				lwidth(none) 
				fcolor(gs11)
				lcolor(gs11)
				)
			(line p1 p, lpattern(solid) lwidth(*1.7) lcolor(gs6))
			, 
				legend(off)
				graphregion(style(none) istyle(none) margin(zero))
				bgcolor(white)
				plotregion(lcolor(black))
			;	
		#delimit cr	
